@@ -15,8 +15,10 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.11',
  'BLDLIBRARY': '-L. -lpython3.11',
- 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-              '-flto=auto -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+ 'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+              '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+              '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+              '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
               '-flto=auto',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
@@ -58,7 +60,8 @@ build_time_vars = {'ABIFLAGS': '',
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                      '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
                       '-flto=auto',
  'CONFIGURE_LDFLAGS_NODIST': '-fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects '
@@ -75,15 +78,15 @@ build_time_vars = {'ABIFLAGS': '',
                 '-Werror=format-security         -fstack-clash-protection '
                 '-fcf-protection -g '
                 '-ffile-prefix-map=/build/python/src=/usr/src/debug/python '
-                "-flto=auto -ffat-lto-objects' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now "
-                "-flto=auto'",
+                "-flto=auto -ffat-lto-objects' 'LDFLAGS=-Wl,-O1 "
+                '-Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                "-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.11.7/coverage.info',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.11.8/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.11.7/lcov-report',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.11.8/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
@@ -635,13 +638,17 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto '
-            '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto',
+ 'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+            '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto '
+            '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+            '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-             '-flto=auto -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
+ 'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+             '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
+             '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+             '-Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs '
              '-flto=auto',
  'LDVERSION': '3.11',
  'LIBC': '',
@@ -1052,23 +1059,27 @@ build_time_vars = {'ABIFLAGS': '',
                    '-g -std=c11 -Werror=implicit-function-declaration '
                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                    '-flto=auto '
-                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                    '-flto=auto -fno-semantic-interposition -flto '
-                    '-fuse-linker-plugin -ffat-lto-objects '
-                    '-flto-partition=none -g',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                    '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
+                    '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+                    '-Wl,-z,relro -Wl,-z,now          '
+                    '-Wl,-z,pack-relative-relocs -flto=auto '
+                    '-fno-semantic-interposition -flto -fuse-linker-plugin '
+                    '-ffat-lto-objects -flto-partition=none -g',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto '
-               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -flto=auto',
+ 'PY_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+               '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto '
+               '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+               '-Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto',
  'PY_LDFLAGS_NODIST': '-fno-semantic-interposition -flto -fuse-linker-plugin '
                       '-ffat-lto-objects -flto-partition=none -g',
- 'PY_LDFLAGS_NOLTO': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                     '-flto=auto '
-                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                     '-flto=auto -fno-lto',
+ 'PY_LDFLAGS_NOLTO': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                     '-Wl,-z,now          -Wl,-z,pack-relative-relocs '
+                     '-flto=auto -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+                     '-Wl,-z,relro -Wl,-z,now          '
+                     '-Wl,-z,pack-relative-relocs -flto=auto -fno-lto',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
@@ -1107,7 +1118,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.7',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.8',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1151,9 +1162,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.7 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.8 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.7 ./python -E '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.11.8 ./python -E '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1184,8 +1195,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.11.7',
- 'abs_srcdir': '/build/python/src/Python-3.11.7',
+ 'abs_builddir': '/build/python/src/Python-3.11.8',
+ 'abs_srcdir': '/build/python/src/Python-3.11.8',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
